==> odoo_19.0.20251004.zip: odoo-19.0.post20251004/odoo/addons/point_of_sale/static/src/app/components/accordion_item/accordion_item.js <==
import { Component, useState, useRef, useEffect, onMounted } from "@odoo/owl";

export class AccordionItem extends Component {
    static template = "pos_hr.AccordionItem";

    static props = {
        disabled: { type: Boolean, optional: true },
        slots: Object,
    };

    static defaultProps = {
        disabled: false,
    };

    setup() {
        this.content = useRef("content_container");
        this.state = useState({
            open: false,
        });
        onMounted(() => {
            this.contentHeight = this.calculateFullHeight();
        });
        useEffect(
            () => {
                this.contentHeight = this.calculateFullHeight();
            },
            () => [this.props.slots.content]
        );
    }

    toggle() {
        if (this.props.disabled) {
            return;
        }
        this.state.open = !this.state.open;
    }

    calculateFullHeight() {
        const children = Array.from(this.content.el.getElementsByClassName("accordion-content"));
        const fullHeight = children.reduce(
            (accumulator, child) => accumulator + Math.min(this.getHiddenHeight(child), 100),
            0
        );
        return fullHeight;
    }

    getHiddenHeight(el) {
        if (!el?.cloneNode) {
            return 0;
        }

        const clone = el.cloneNode(true);

        Object.assign(clone.style, {
            overflow: "visible",
            height: "auto",
            maxHeight: "none",
            opacity: "0",
            visibility: "hidden",
            display: "block",
        });

        el.after(clone);
        const height = clone.offsetHeight;
        clone.remove();

        return height;
    }
}

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/point_of_sale/static/src/app/components/accordion_item/accordion_item.js <==
import { useLayoutEffect, useRef, useState } from "@web/owl2/utils";
import { Component, onMounted } from "@odoo/owl";

export class AccordionItem extends Component {
    static template = "pos_hr.AccordionItem";

    static props = {
        disabled: { type: Boolean, optional: true },
        slots: Object,
    };

    static defaultProps = {
        disabled: false,
    };

    setup() {
        this.content = useRef("content_container");
        this.state = useState({
            open: false,
        });
        onMounted(() => {
            this.contentHeight = this.calculateFullHeight();
        });
        useLayoutEffect(
            () => {
                this.contentHeight = this.calculateFullHeight();
            },
            () => [this.props.slots.content]
        );
    }

    toggle() {
        if (this.props.disabled) {
            return;
        }
        this.state.open = !this.state.open;
    }

    calculateFullHeight() {
        const children = Array.from(this.content.el.getElementsByClassName("accordion-content"));
        const fullHeight = children.reduce(
            (accumulator, child) => accumulator + Math.min(this.getHiddenHeight(child), 100),
            0
        );
        return fullHeight;
    }

    getHiddenHeight(el) {
        if (!el?.cloneNode) {
            return 0;
        }

        const clone = el.cloneNode(true);

        Object.assign(clone.style, {
            overflow: "visible",
            height: "auto",
            maxHeight: "none",
            opacity: "0",
            visibility: "hidden",
            display: "block",
        });

        el.after(clone);
        const height = clone.offsetHeight;
        clone.remove();

        return height;
    }
}
